from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Storage.Streams
import win32more.Windows.UI
import win32more.Windows.UI.Text
import win32more.Windows.Win32.System.WinRT
class CaretType(Enum, Int32):
    Normal = 0
    Null = 1
class ContentLinkInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.IContentLinkInfo
    _classid_ = 'Windows.UI.Text.ContentLinkInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Text.ContentLinkInfo.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Text.ContentLinkInfo: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.UI.Text.IContentLinkInfo) -> UInt32: ...
    @winrt_mixinmethod
    def put_Id(self: win32more.Windows.UI.Text.IContentLinkInfo, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayText(self: win32more.Windows.UI.Text.IContentLinkInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayText(self: win32more.Windows.UI.Text.IContentLinkInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryText(self: win32more.Windows.UI.Text.IContentLinkInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SecondaryText(self: win32more.Windows.UI.Text.IContentLinkInfo, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.UI.Text.IContentLinkInfo) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Uri(self: win32more.Windows.UI.Text.IContentLinkInfo, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_LinkContentKind(self: win32more.Windows.UI.Text.IContentLinkInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_LinkContentKind(self: win32more.Windows.UI.Text.IContentLinkInfo, value: WinRT_String) -> Void: ...
    DisplayText = property(get_DisplayText, put_DisplayText)
    Id = property(get_Id, put_Id)
    LinkContentKind = property(get_LinkContentKind, put_LinkContentKind)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    Uri = property(get_Uri, put_Uri)
class FindOptions(Enum, UInt32):
    None_ = 0
    Word = 2
    Case = 4
class FontStretch(Enum, Int32):
    Undefined = 0
    UltraCondensed = 1
    ExtraCondensed = 2
    Condensed = 3
    SemiCondensed = 4
    Normal = 5
    SemiExpanded = 6
    Expanded = 7
    ExtraExpanded = 8
    UltraExpanded = 9
class FontStyle(Enum, Int32):
    Normal = 0
    Oblique = 1
    Italic = 2
class FontWeight(Structure):
    Weight: UInt16
class _FontWeights_Meta_(ComPtr.__class__):
    pass
class FontWeights(ComPtr, metaclass=_FontWeights_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.IFontWeights
    _classid_ = 'Windows.UI.Text.FontWeights'
    @winrt_classmethod
    def get_Black(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Bold(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_ExtraBlack(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_ExtraBold(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_ExtraLight(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Light(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Medium(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Normal(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_SemiBold(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_SemiLight(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_classmethod
    def get_Thin(cls: win32more.Windows.UI.Text.IFontWeightsStatics) -> win32more.Windows.UI.Text.FontWeight: ...
    _FontWeights_Meta_.Black = property(get_Black, None)
    _FontWeights_Meta_.Bold = property(get_Bold, None)
    _FontWeights_Meta_.ExtraBlack = property(get_ExtraBlack, None)
    _FontWeights_Meta_.ExtraBold = property(get_ExtraBold, None)
    _FontWeights_Meta_.ExtraLight = property(get_ExtraLight, None)
    _FontWeights_Meta_.Light = property(get_Light, None)
    _FontWeights_Meta_.Medium = property(get_Medium, None)
    _FontWeights_Meta_.Normal = property(get_Normal, None)
    _FontWeights_Meta_.SemiBold = property(get_SemiBold, None)
    _FontWeights_Meta_.SemiLight = property(get_SemiLight, None)
    _FontWeights_Meta_.Thin = property(get_Thin, None)
class FormatEffect(Enum, Int32):
    Off = 0
    On = 1
    Toggle = 2
    Undefined = 3
class HorizontalCharacterAlignment(Enum, Int32):
    Left = 0
    Right = 1
    Center = 2
class IContentLinkInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.IContentLinkInfo'
    _iid_ = Guid('{1ed52525-1c5f-48cb-b335-78b50a2ee642}')
    @winrt_commethod(6)
    def get_Id(self) -> UInt32: ...
    @winrt_commethod(7)
    def put_Id(self, value: UInt32) -> Void: ...
    @winrt_commethod(8)
    def get_DisplayText(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_DisplayText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SecondaryText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_SecondaryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(13)
    def put_Uri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(14)
    def get_LinkContentKind(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_LinkContentKind(self, value: WinRT_String) -> Void: ...
    DisplayText = property(get_DisplayText, put_DisplayText)
    Id = property(get_Id, put_Id)
    LinkContentKind = property(get_LinkContentKind, put_LinkContentKind)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    Uri = property(get_Uri, put_Uri)
class IFontWeights(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.IFontWeights'
    _iid_ = Guid('{7880a444-01ab-4997-8517-df822a0c45f1}')
class IFontWeightsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.IFontWeightsStatics'
    _iid_ = Guid('{b3b579d5-1ba9-48eb-9dad-c095e8c23ba3}')
    @winrt_commethod(6)
    def get_Black(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(7)
    def get_Bold(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(8)
    def get_ExtraBlack(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(9)
    def get_ExtraBold(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(10)
    def get_ExtraLight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def get_Light(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(12)
    def get_Medium(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(13)
    def get_Normal(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(14)
    def get_SemiBold(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(15)
    def get_SemiLight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(16)
    def get_Thin(self) -> win32more.Windows.UI.Text.FontWeight: ...
    Black = property(get_Black, None)
    Bold = property(get_Bold, None)
    ExtraBlack = property(get_ExtraBlack, None)
    ExtraBold = property(get_ExtraBold, None)
    ExtraLight = property(get_ExtraLight, None)
    Light = property(get_Light, None)
    Medium = property(get_Medium, None)
    Normal = property(get_Normal, None)
    SemiBold = property(get_SemiBold, None)
    SemiLight = property(get_SemiLight, None)
    Thin = property(get_Thin, None)
class IRichEditTextRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.IRichEditTextRange'
    _iid_ = Guid('{374e3515-ba8a-4a6e-8c59-0dde3d0cf5cd}')
    @winrt_commethod(6)
    def get_ContentLinkInfo(self) -> win32more.Windows.UI.Text.ContentLinkInfo: ...
    @winrt_commethod(7)
    def put_ContentLinkInfo(self, value: win32more.Windows.UI.Text.ContentLinkInfo) -> Void: ...
    ContentLinkInfo = property(get_ContentLinkInfo, put_ContentLinkInfo)
class ITextCharacterFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextCharacterFormat'
    _iid_ = Guid('{5adef3db-05fb-442d-8065-642afea02ced}')
    @winrt_commethod(6)
    def get_AllCaps(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(7)
    def put_AllCaps(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(8)
    def get_BackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def put_BackgroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(10)
    def get_Bold(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(11)
    def put_Bold(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(12)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(13)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(14)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(15)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(16)
    def get_ForegroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(17)
    def put_ForegroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(18)
    def get_Hidden(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(19)
    def put_Hidden(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(20)
    def get_Italic(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(21)
    def put_Italic(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(22)
    def get_Kerning(self) -> Single: ...
    @winrt_commethod(23)
    def put_Kerning(self, value: Single) -> Void: ...
    @winrt_commethod(24)
    def get_LanguageTag(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def put_LanguageTag(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(26)
    def get_LinkType(self) -> win32more.Windows.UI.Text.LinkType: ...
    @winrt_commethod(27)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(28)
    def put_Name(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(29)
    def get_Outline(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(30)
    def put_Outline(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(31)
    def get_Position(self) -> Single: ...
    @winrt_commethod(32)
    def put_Position(self, value: Single) -> Void: ...
    @winrt_commethod(33)
    def get_ProtectedText(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(34)
    def put_ProtectedText(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(35)
    def get_Size(self) -> Single: ...
    @winrt_commethod(36)
    def put_Size(self, value: Single) -> Void: ...
    @winrt_commethod(37)
    def get_SmallCaps(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(38)
    def put_SmallCaps(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(39)
    def get_Spacing(self) -> Single: ...
    @winrt_commethod(40)
    def put_Spacing(self, value: Single) -> Void: ...
    @winrt_commethod(41)
    def get_Strikethrough(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(42)
    def put_Strikethrough(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(43)
    def get_Subscript(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(44)
    def put_Subscript(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(45)
    def get_Superscript(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(46)
    def put_Superscript(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(47)
    def get_TextScript(self) -> win32more.Windows.UI.Text.TextScript: ...
    @winrt_commethod(48)
    def put_TextScript(self, value: win32more.Windows.UI.Text.TextScript) -> Void: ...
    @winrt_commethod(49)
    def get_Underline(self) -> win32more.Windows.UI.Text.UnderlineType: ...
    @winrt_commethod(50)
    def put_Underline(self, value: win32more.Windows.UI.Text.UnderlineType) -> Void: ...
    @winrt_commethod(51)
    def get_Weight(self) -> Int32: ...
    @winrt_commethod(52)
    def put_Weight(self, value: Int32) -> Void: ...
    @winrt_commethod(53)
    def SetClone(self, value: win32more.Windows.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_commethod(54)
    def GetClone(self) -> win32more.Windows.UI.Text.ITextCharacterFormat: ...
    @winrt_commethod(55)
    def IsEqual(self, format: win32more.Windows.UI.Text.ITextCharacterFormat) -> Boolean: ...
    AllCaps = property(get_AllCaps, put_AllCaps)
    BackgroundColor = property(get_BackgroundColor, put_BackgroundColor)
    Bold = property(get_Bold, put_Bold)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    ForegroundColor = property(get_ForegroundColor, put_ForegroundColor)
    Hidden = property(get_Hidden, put_Hidden)
    Italic = property(get_Italic, put_Italic)
    Kerning = property(get_Kerning, put_Kerning)
    LanguageTag = property(get_LanguageTag, put_LanguageTag)
    LinkType = property(get_LinkType, None)
    Name = property(get_Name, put_Name)
    Outline = property(get_Outline, put_Outline)
    Position = property(get_Position, put_Position)
    ProtectedText = property(get_ProtectedText, put_ProtectedText)
    Size = property(get_Size, put_Size)
    SmallCaps = property(get_SmallCaps, put_SmallCaps)
    Spacing = property(get_Spacing, put_Spacing)
    Strikethrough = property(get_Strikethrough, put_Strikethrough)
    Subscript = property(get_Subscript, put_Subscript)
    Superscript = property(get_Superscript, put_Superscript)
    TextScript = property(get_TextScript, put_TextScript)
    Underline = property(get_Underline, put_Underline)
    Weight = property(get_Weight, put_Weight)
class ITextConstantsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextConstantsStatics'
    _iid_ = Guid('{779e7c33-189d-4bfa-97c8-10db135d976e}')
    @winrt_commethod(6)
    def get_AutoColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def get_MinUnitCount(self) -> Int32: ...
    @winrt_commethod(8)
    def get_MaxUnitCount(self) -> Int32: ...
    @winrt_commethod(9)
    def get_UndefinedColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(10)
    def get_UndefinedFloatValue(self) -> Single: ...
    @winrt_commethod(11)
    def get_UndefinedInt32Value(self) -> Int32: ...
    @winrt_commethod(12)
    def get_UndefinedFontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(13)
    def get_UndefinedFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    AutoColor = property(get_AutoColor, None)
    MaxUnitCount = property(get_MaxUnitCount, None)
    MinUnitCount = property(get_MinUnitCount, None)
    UndefinedColor = property(get_UndefinedColor, None)
    UndefinedFloatValue = property(get_UndefinedFloatValue, None)
    UndefinedFontStretch = property(get_UndefinedFontStretch, None)
    UndefinedFontStyle = property(get_UndefinedFontStyle, None)
    UndefinedInt32Value = property(get_UndefinedInt32Value, None)
class ITextDocument(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextDocument'
    _iid_ = Guid('{beee4ddb-90b2-408c-a2f6-0a0ac31e33e4}')
    @winrt_commethod(6)
    def get_CaretType(self) -> win32more.Windows.UI.Text.CaretType: ...
    @winrt_commethod(7)
    def put_CaretType(self, value: win32more.Windows.UI.Text.CaretType) -> Void: ...
    @winrt_commethod(8)
    def get_DefaultTabStop(self) -> Single: ...
    @winrt_commethod(9)
    def put_DefaultTabStop(self, value: Single) -> Void: ...
    @winrt_commethod(10)
    def get_Selection(self) -> win32more.Windows.UI.Text.ITextSelection: ...
    @winrt_commethod(11)
    def get_UndoLimit(self) -> UInt32: ...
    @winrt_commethod(12)
    def put_UndoLimit(self, value: UInt32) -> Void: ...
    @winrt_commethod(13)
    def CanCopy(self) -> Boolean: ...
    @winrt_commethod(14)
    def CanPaste(self) -> Boolean: ...
    @winrt_commethod(15)
    def CanRedo(self) -> Boolean: ...
    @winrt_commethod(16)
    def CanUndo(self) -> Boolean: ...
    @winrt_commethod(17)
    def ApplyDisplayUpdates(self) -> Int32: ...
    @winrt_commethod(18)
    def BatchDisplayUpdates(self) -> Int32: ...
    @winrt_commethod(19)
    def BeginUndoGroup(self) -> Void: ...
    @winrt_commethod(20)
    def EndUndoGroup(self) -> Void: ...
    @winrt_commethod(21)
    def GetDefaultCharacterFormat(self) -> win32more.Windows.UI.Text.ITextCharacterFormat: ...
    @winrt_commethod(22)
    def GetDefaultParagraphFormat(self) -> win32more.Windows.UI.Text.ITextParagraphFormat: ...
    @winrt_commethod(23)
    def GetRange(self, startPosition: Int32, endPosition: Int32) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_commethod(24)
    def GetRangeFromPoint(self, point: win32more.Windows.Foundation.Point, options: win32more.Windows.UI.Text.PointOptions) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_commethod(25)
    def GetText(self, options: win32more.Windows.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_commethod(26)
    def LoadFromStream(self, options: win32more.Windows.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(27)
    def Redo(self) -> Void: ...
    @winrt_commethod(28)
    def SaveToStream(self, options: win32more.Windows.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(29)
    def SetDefaultCharacterFormat(self, value: win32more.Windows.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_commethod(30)
    def SetDefaultParagraphFormat(self, value: win32more.Windows.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_commethod(31)
    def SetText(self, options: win32more.Windows.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_commethod(32)
    def Undo(self) -> Void: ...
    CaretType = property(get_CaretType, put_CaretType)
    DefaultTabStop = property(get_DefaultTabStop, put_DefaultTabStop)
    Selection = property(get_Selection, None)
    UndoLimit = property(get_UndoLimit, put_UndoLimit)
class ITextDocument2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextDocument2'
    _iid_ = Guid('{f2311112-8c89-49c9-9118-f057cbb814ee}')
    @winrt_commethod(6)
    def get_AlignmentIncludesTrailingWhitespace(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AlignmentIncludesTrailingWhitespace(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IgnoreTrailingCharacterSpacing(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IgnoreTrailingCharacterSpacing(self, value: Boolean) -> Void: ...
    AlignmentIncludesTrailingWhitespace = property(get_AlignmentIncludesTrailingWhitespace, put_AlignmentIncludesTrailingWhitespace)
    IgnoreTrailingCharacterSpacing = property(get_IgnoreTrailingCharacterSpacing, put_IgnoreTrailingCharacterSpacing)
class ITextDocument3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextDocument3'
    _iid_ = Guid('{75ab03a1-a6f8-441d-aa18-0a851d6e5e3c}')
    @winrt_commethod(6)
    def ClearUndoRedoHistory(self) -> Void: ...
class ITextDocument4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextDocument4'
    _iid_ = Guid('{619c20f2-cb3b-4521-981f-2865b1b93f04}')
    @winrt_commethod(6)
    def SetMath(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def GetMath(self, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_commethod(8)
    def SetMathMode(self, mode: win32more.Windows.UI.Text.RichEditMathMode) -> Void: ...
class ITextParagraphFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextParagraphFormat'
    _iid_ = Guid('{2cf8cfa6-4676-498a-93f5-bbdbfc0bd883}')
    @winrt_commethod(6)
    def get_Alignment(self) -> win32more.Windows.UI.Text.ParagraphAlignment: ...
    @winrt_commethod(7)
    def put_Alignment(self, value: win32more.Windows.UI.Text.ParagraphAlignment) -> Void: ...
    @winrt_commethod(8)
    def get_FirstLineIndent(self) -> Single: ...
    @winrt_commethod(9)
    def get_KeepTogether(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(10)
    def put_KeepTogether(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(11)
    def get_KeepWithNext(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(12)
    def put_KeepWithNext(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(13)
    def get_LeftIndent(self) -> Single: ...
    @winrt_commethod(14)
    def get_LineSpacing(self) -> Single: ...
    @winrt_commethod(15)
    def get_LineSpacingRule(self) -> win32more.Windows.UI.Text.LineSpacingRule: ...
    @winrt_commethod(16)
    def get_ListAlignment(self) -> win32more.Windows.UI.Text.MarkerAlignment: ...
    @winrt_commethod(17)
    def put_ListAlignment(self, value: win32more.Windows.UI.Text.MarkerAlignment) -> Void: ...
    @winrt_commethod(18)
    def get_ListLevelIndex(self) -> Int32: ...
    @winrt_commethod(19)
    def put_ListLevelIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(20)
    def get_ListStart(self) -> Int32: ...
    @winrt_commethod(21)
    def put_ListStart(self, value: Int32) -> Void: ...
    @winrt_commethod(22)
    def get_ListStyle(self) -> win32more.Windows.UI.Text.MarkerStyle: ...
    @winrt_commethod(23)
    def put_ListStyle(self, value: win32more.Windows.UI.Text.MarkerStyle) -> Void: ...
    @winrt_commethod(24)
    def get_ListTab(self) -> Single: ...
    @winrt_commethod(25)
    def put_ListTab(self, value: Single) -> Void: ...
    @winrt_commethod(26)
    def get_ListType(self) -> win32more.Windows.UI.Text.MarkerType: ...
    @winrt_commethod(27)
    def put_ListType(self, value: win32more.Windows.UI.Text.MarkerType) -> Void: ...
    @winrt_commethod(28)
    def get_NoLineNumber(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(29)
    def put_NoLineNumber(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(30)
    def get_PageBreakBefore(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(31)
    def put_PageBreakBefore(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(32)
    def get_RightIndent(self) -> Single: ...
    @winrt_commethod(33)
    def put_RightIndent(self, value: Single) -> Void: ...
    @winrt_commethod(34)
    def get_RightToLeft(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(35)
    def put_RightToLeft(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(36)
    def get_Style(self) -> win32more.Windows.UI.Text.ParagraphStyle: ...
    @winrt_commethod(37)
    def put_Style(self, value: win32more.Windows.UI.Text.ParagraphStyle) -> Void: ...
    @winrt_commethod(38)
    def get_SpaceAfter(self) -> Single: ...
    @winrt_commethod(39)
    def put_SpaceAfter(self, value: Single) -> Void: ...
    @winrt_commethod(40)
    def get_SpaceBefore(self) -> Single: ...
    @winrt_commethod(41)
    def put_SpaceBefore(self, value: Single) -> Void: ...
    @winrt_commethod(42)
    def get_WidowControl(self) -> win32more.Windows.UI.Text.FormatEffect: ...
    @winrt_commethod(43)
    def put_WidowControl(self, value: win32more.Windows.UI.Text.FormatEffect) -> Void: ...
    @winrt_commethod(44)
    def get_TabCount(self) -> Int32: ...
    @winrt_commethod(45)
    def AddTab(self, position: Single, align: win32more.Windows.UI.Text.TabAlignment, leader: win32more.Windows.UI.Text.TabLeader) -> Void: ...
    @winrt_commethod(46)
    def ClearAllTabs(self) -> Void: ...
    @winrt_commethod(47)
    def DeleteTab(self, position: Single) -> Void: ...
    @winrt_commethod(48)
    def GetClone(self) -> win32more.Windows.UI.Text.ITextParagraphFormat: ...
    @winrt_commethod(49)
    def GetTab(self, index: Int32, position: POINTER(Single), align: POINTER(win32more.Windows.UI.Text.TabAlignment), leader: POINTER(win32more.Windows.UI.Text.TabLeader)) -> Void: ...
    @winrt_commethod(50)
    def IsEqual(self, format: win32more.Windows.UI.Text.ITextParagraphFormat) -> Boolean: ...
    @winrt_commethod(51)
    def SetClone(self, format: win32more.Windows.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_commethod(52)
    def SetIndents(self, start: Single, left: Single, right: Single) -> Void: ...
    @winrt_commethod(53)
    def SetLineSpacing(self, rule: win32more.Windows.UI.Text.LineSpacingRule, spacing: Single) -> Void: ...
    Alignment = property(get_Alignment, put_Alignment)
    FirstLineIndent = property(get_FirstLineIndent, None)
    KeepTogether = property(get_KeepTogether, put_KeepTogether)
    KeepWithNext = property(get_KeepWithNext, put_KeepWithNext)
    LeftIndent = property(get_LeftIndent, None)
    LineSpacing = property(get_LineSpacing, None)
    LineSpacingRule = property(get_LineSpacingRule, None)
    ListAlignment = property(get_ListAlignment, put_ListAlignment)
    ListLevelIndex = property(get_ListLevelIndex, put_ListLevelIndex)
    ListStart = property(get_ListStart, put_ListStart)
    ListStyle = property(get_ListStyle, put_ListStyle)
    ListTab = property(get_ListTab, put_ListTab)
    ListType = property(get_ListType, put_ListType)
    NoLineNumber = property(get_NoLineNumber, put_NoLineNumber)
    PageBreakBefore = property(get_PageBreakBefore, put_PageBreakBefore)
    RightIndent = property(get_RightIndent, put_RightIndent)
    RightToLeft = property(get_RightToLeft, put_RightToLeft)
    SpaceAfter = property(get_SpaceAfter, put_SpaceAfter)
    SpaceBefore = property(get_SpaceBefore, put_SpaceBefore)
    Style = property(get_Style, put_Style)
    TabCount = property(get_TabCount, None)
    WidowControl = property(get_WidowControl, put_WidowControl)
class ITextRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextRange'
    _iid_ = Guid('{5b9e4e57-c072-42a0-8945-af503ee54768}')
    @winrt_commethod(6)
    def get_Character(self) -> Char: ...
    @winrt_commethod(7)
    def put_Character(self, value: Char) -> Void: ...
    @winrt_commethod(8)
    def get_CharacterFormat(self) -> win32more.Windows.UI.Text.ITextCharacterFormat: ...
    @winrt_commethod(9)
    def put_CharacterFormat(self, value: win32more.Windows.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_commethod(10)
    def get_FormattedText(self) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_commethod(11)
    def put_FormattedText(self, value: win32more.Windows.UI.Text.ITextRange) -> Void: ...
    @winrt_commethod(12)
    def get_EndPosition(self) -> Int32: ...
    @winrt_commethod(13)
    def put_EndPosition(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Gravity(self) -> win32more.Windows.UI.Text.RangeGravity: ...
    @winrt_commethod(15)
    def put_Gravity(self, value: win32more.Windows.UI.Text.RangeGravity) -> Void: ...
    @winrt_commethod(16)
    def get_Length(self) -> Int32: ...
    @winrt_commethod(17)
    def get_Link(self) -> WinRT_String: ...
    @winrt_commethod(18)
    def put_Link(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(19)
    def get_ParagraphFormat(self) -> win32more.Windows.UI.Text.ITextParagraphFormat: ...
    @winrt_commethod(20)
    def put_ParagraphFormat(self, value: win32more.Windows.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_commethod(21)
    def get_StartPosition(self) -> Int32: ...
    @winrt_commethod(22)
    def put_StartPosition(self, value: Int32) -> Void: ...
    @winrt_commethod(23)
    def get_StoryLength(self) -> Int32: ...
    @winrt_commethod(24)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(26)
    def CanPaste(self, format: Int32) -> Boolean: ...
    @winrt_commethod(27)
    def ChangeCase(self, value: win32more.Windows.UI.Text.LetterCase) -> Void: ...
    @winrt_commethod(28)
    def Collapse(self, value: Boolean) -> Void: ...
    @winrt_commethod(29)
    def Copy(self) -> Void: ...
    @winrt_commethod(30)
    def Cut(self) -> Void: ...
    @winrt_commethod(31)
    def Delete(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(32)
    def EndOf(self, unit: win32more.Windows.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_commethod(33)
    def Expand(self, unit: win32more.Windows.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_commethod(34)
    def FindText(self, value: WinRT_String, scanLength: Int32, options: win32more.Windows.UI.Text.FindOptions) -> Int32: ...
    @winrt_commethod(35)
    def GetCharacterUtf32(self, value: POINTER(UInt32), offset: Int32) -> Void: ...
    @winrt_commethod(36)
    def GetClone(self) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_commethod(37)
    def GetIndex(self, unit: win32more.Windows.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_commethod(38)
    def GetPoint(self, horizontalAlign: win32more.Windows.UI.Text.HorizontalCharacterAlignment, verticalAlign: win32more.Windows.UI.Text.VerticalCharacterAlignment, options: win32more.Windows.UI.Text.PointOptions, point: POINTER(win32more.Windows.Foundation.Point)) -> Void: ...
    @winrt_commethod(39)
    def GetRect(self, options: win32more.Windows.UI.Text.PointOptions, rect: POINTER(win32more.Windows.Foundation.Rect), hit: POINTER(Int32)) -> Void: ...
    @winrt_commethod(40)
    def GetText(self, options: win32more.Windows.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_commethod(41)
    def GetTextViaStream(self, options: win32more.Windows.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(42)
    def InRange(self, range: win32more.Windows.UI.Text.ITextRange) -> Boolean: ...
    @winrt_commethod(43)
    def InsertImage(self, width: Int32, height: Int32, ascent: Int32, verticalAlign: win32more.Windows.UI.Text.VerticalCharacterAlignment, alternateText: WinRT_String, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(44)
    def InStory(self, range: win32more.Windows.UI.Text.ITextRange) -> Boolean: ...
    @winrt_commethod(45)
    def IsEqual(self, range: win32more.Windows.UI.Text.ITextRange) -> Boolean: ...
    @winrt_commethod(46)
    def Move(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(47)
    def MoveEnd(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(48)
    def MoveStart(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_commethod(49)
    def Paste(self, format: Int32) -> Void: ...
    @winrt_commethod(50)
    def ScrollIntoView(self, value: win32more.Windows.UI.Text.PointOptions) -> Void: ...
    @winrt_commethod(51)
    def MatchSelection(self) -> Void: ...
    @winrt_commethod(52)
    def SetIndex(self, unit: win32more.Windows.UI.Text.TextRangeUnit, index: Int32, extend: Boolean) -> Void: ...
    @winrt_commethod(53)
    def SetPoint(self, point: win32more.Windows.Foundation.Point, options: win32more.Windows.UI.Text.PointOptions, extend: Boolean) -> Void: ...
    @winrt_commethod(54)
    def SetRange(self, startPosition: Int32, endPosition: Int32) -> Void: ...
    @winrt_commethod(55)
    def SetText(self, options: win32more.Windows.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_commethod(56)
    def SetTextViaStream(self, options: win32more.Windows.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_commethod(57)
    def StartOf(self, unit: win32more.Windows.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    Character = property(get_Character, put_Character)
    CharacterFormat = property(get_CharacterFormat, put_CharacterFormat)
    EndPosition = property(get_EndPosition, put_EndPosition)
    FormattedText = property(get_FormattedText, put_FormattedText)
    Gravity = property(get_Gravity, put_Gravity)
    Length = property(get_Length, None)
    Link = property(get_Link, put_Link)
    ParagraphFormat = property(get_ParagraphFormat, put_ParagraphFormat)
    StartPosition = property(get_StartPosition, put_StartPosition)
    StoryLength = property(get_StoryLength, None)
    Text = property(get_Text, put_Text)
class ITextSelection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.ITextSelection'
    _iid_ = Guid('{a6d36724-f28f-430a-b2cf-c343671ec0e9}')
    @winrt_commethod(6)
    def get_Options(self) -> win32more.Windows.UI.Text.SelectionOptions: ...
    @winrt_commethod(7)
    def put_Options(self, value: win32more.Windows.UI.Text.SelectionOptions) -> Void: ...
    @winrt_commethod(8)
    def get_Type(self) -> win32more.Windows.UI.Text.SelectionType: ...
    @winrt_commethod(9)
    def EndKey(self, unit: win32more.Windows.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_commethod(10)
    def HomeKey(self, unit: win32more.Windows.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_commethod(11)
    def MoveDown(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(12)
    def MoveLeft(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(13)
    def MoveRight(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(14)
    def MoveUp(self, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32, extend: Boolean) -> Int32: ...
    @winrt_commethod(15)
    def TypeText(self, value: WinRT_String) -> Void: ...
    Options = property(get_Options, put_Options)
    Type = property(get_Type, None)
class LetterCase(Enum, Int32):
    Lower = 0
    Upper = 1
class LineSpacingRule(Enum, Int32):
    Undefined = 0
    Single = 1
    OneAndHalf = 2
    Double = 3
    AtLeast = 4
    Exactly = 5
    Multiple = 6
    Percent = 7
class LinkType(Enum, Int32):
    Undefined = 0
    NotALink = 1
    ClientLink = 2
    FriendlyLinkName = 3
    FriendlyLinkAddress = 4
    AutoLink = 5
    AutoLinkEmail = 6
    AutoLinkPhone = 7
    AutoLinkPath = 8
class MarkerAlignment(Enum, Int32):
    Undefined = 0
    Left = 1
    Center = 2
    Right = 3
class MarkerStyle(Enum, Int32):
    Undefined = 0
    Parenthesis = 1
    Parentheses = 2
    Period = 3
    Plain = 4
    Minus = 5
    NoNumber = 6
class MarkerType(Enum, Int32):
    Undefined = 0
    None_ = 1
    Bullet = 2
    Arabic = 3
    LowercaseEnglishLetter = 4
    UppercaseEnglishLetter = 5
    LowercaseRoman = 6
    UppercaseRoman = 7
    UnicodeSequence = 8
    CircledNumber = 9
    BlackCircleWingding = 10
    WhiteCircleWingding = 11
    ArabicWide = 12
    SimplifiedChinese = 13
    TraditionalChinese = 14
    JapanSimplifiedChinese = 15
    JapanKorea = 16
    ArabicDictionary = 17
    ArabicAbjad = 18
    Hebrew = 19
    ThaiAlphabetic = 20
    ThaiNumeric = 21
    DevanagariVowel = 22
    DevanagariConsonant = 23
    DevanagariNumeric = 24
class ParagraphAlignment(Enum, Int32):
    Undefined = 0
    Left = 1
    Center = 2
    Right = 3
    Justify = 4
class ParagraphStyle(Enum, Int32):
    Undefined = 0
    None_ = 1
    Normal = 2
    Heading1 = 3
    Heading2 = 4
    Heading3 = 5
    Heading4 = 6
    Heading5 = 7
    Heading6 = 8
    Heading7 = 9
    Heading8 = 10
    Heading9 = 11
class PointOptions(Enum, UInt32):
    None_ = 0
    IncludeInset = 1
    Start = 32
    ClientCoordinates = 256
    AllowOffClient = 512
    Transform = 1024
    NoHorizontalScroll = 65536
    NoVerticalScroll = 262144
class RangeGravity(Enum, Int32):
    UIBehavior = 0
    Backward = 1
    Forward = 2
    Inward = 3
    Outward = 4
class RichEditMathMode(Enum, Int32):
    NoMath = 0
    MathOnly = 1
class RichEditTextDocument(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.ITextDocument
    _classid_ = 'Windows.UI.Text.RichEditTextDocument'
    @winrt_mixinmethod
    def get_AlignmentIncludesTrailingWhitespace(self: win32more.Windows.UI.Text.ITextDocument2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AlignmentIncludesTrailingWhitespace(self: win32more.Windows.UI.Text.ITextDocument2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IgnoreTrailingCharacterSpacing(self: win32more.Windows.UI.Text.ITextDocument2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IgnoreTrailingCharacterSpacing(self: win32more.Windows.UI.Text.ITextDocument2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def ClearUndoRedoHistory(self: win32more.Windows.UI.Text.ITextDocument3) -> Void: ...
    @winrt_mixinmethod
    def SetMath(self: win32more.Windows.UI.Text.ITextDocument4, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetMath(self: win32more.Windows.UI.Text.ITextDocument4, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_mixinmethod
    def SetMathMode(self: win32more.Windows.UI.Text.ITextDocument4, mode: win32more.Windows.UI.Text.RichEditMathMode) -> Void: ...
    @winrt_mixinmethod
    def get_CaretType(self: win32more.Windows.UI.Text.ITextDocument) -> win32more.Windows.UI.Text.CaretType: ...
    @winrt_mixinmethod
    def put_CaretType(self: win32more.Windows.UI.Text.ITextDocument, value: win32more.Windows.UI.Text.CaretType) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultTabStop(self: win32more.Windows.UI.Text.ITextDocument) -> Single: ...
    @winrt_mixinmethod
    def put_DefaultTabStop(self: win32more.Windows.UI.Text.ITextDocument, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_Selection(self: win32more.Windows.UI.Text.ITextDocument) -> win32more.Windows.UI.Text.ITextSelection: ...
    @winrt_mixinmethod
    def get_UndoLimit(self: win32more.Windows.UI.Text.ITextDocument) -> UInt32: ...
    @winrt_mixinmethod
    def put_UndoLimit(self: win32more.Windows.UI.Text.ITextDocument, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def CanCopy(self: win32more.Windows.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def CanPaste(self: win32more.Windows.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def CanRedo(self: win32more.Windows.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def CanUndo(self: win32more.Windows.UI.Text.ITextDocument) -> Boolean: ...
    @winrt_mixinmethod
    def ApplyDisplayUpdates(self: win32more.Windows.UI.Text.ITextDocument) -> Int32: ...
    @winrt_mixinmethod
    def BatchDisplayUpdates(self: win32more.Windows.UI.Text.ITextDocument) -> Int32: ...
    @winrt_mixinmethod
    def BeginUndoGroup(self: win32more.Windows.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def EndUndoGroup(self: win32more.Windows.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def GetDefaultCharacterFormat(self: win32more.Windows.UI.Text.ITextDocument) -> win32more.Windows.UI.Text.ITextCharacterFormat: ...
    @winrt_mixinmethod
    def GetDefaultParagraphFormat(self: win32more.Windows.UI.Text.ITextDocument) -> win32more.Windows.UI.Text.ITextParagraphFormat: ...
    @winrt_mixinmethod
    def GetRange(self: win32more.Windows.UI.Text.ITextDocument, startPosition: Int32, endPosition: Int32) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def GetRangeFromPoint(self: win32more.Windows.UI.Text.ITextDocument, point: win32more.Windows.Foundation.Point, options: win32more.Windows.UI.Text.PointOptions) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def GetText(self: win32more.Windows.UI.Text.ITextDocument, options: win32more.Windows.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_mixinmethod
    def LoadFromStream(self: win32more.Windows.UI.Text.ITextDocument, options: win32more.Windows.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def Redo(self: win32more.Windows.UI.Text.ITextDocument) -> Void: ...
    @winrt_mixinmethod
    def SaveToStream(self: win32more.Windows.UI.Text.ITextDocument, options: win32more.Windows.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def SetDefaultCharacterFormat(self: win32more.Windows.UI.Text.ITextDocument, value: win32more.Windows.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_mixinmethod
    def SetDefaultParagraphFormat(self: win32more.Windows.UI.Text.ITextDocument, value: win32more.Windows.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_mixinmethod
    def SetText(self: win32more.Windows.UI.Text.ITextDocument, options: win32more.Windows.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Undo(self: win32more.Windows.UI.Text.ITextDocument) -> Void: ...
    AlignmentIncludesTrailingWhitespace = property(get_AlignmentIncludesTrailingWhitespace, put_AlignmentIncludesTrailingWhitespace)
    CaretType = property(get_CaretType, put_CaretType)
    DefaultTabStop = property(get_DefaultTabStop, put_DefaultTabStop)
    IgnoreTrailingCharacterSpacing = property(get_IgnoreTrailingCharacterSpacing, put_IgnoreTrailingCharacterSpacing)
    Selection = property(get_Selection, None)
    UndoLimit = property(get_UndoLimit, put_UndoLimit)
class RichEditTextRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.ITextRange
    _classid_ = 'Windows.UI.Text.RichEditTextRange'
    @winrt_mixinmethod
    def get_ContentLinkInfo(self: win32more.Windows.UI.Text.IRichEditTextRange) -> win32more.Windows.UI.Text.ContentLinkInfo: ...
    @winrt_mixinmethod
    def put_ContentLinkInfo(self: win32more.Windows.UI.Text.IRichEditTextRange, value: win32more.Windows.UI.Text.ContentLinkInfo) -> Void: ...
    @winrt_mixinmethod
    def get_Character(self: win32more.Windows.UI.Text.ITextRange) -> Char: ...
    @winrt_mixinmethod
    def put_Character(self: win32more.Windows.UI.Text.ITextRange, value: Char) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterFormat(self: win32more.Windows.UI.Text.ITextRange) -> win32more.Windows.UI.Text.ITextCharacterFormat: ...
    @winrt_mixinmethod
    def put_CharacterFormat(self: win32more.Windows.UI.Text.ITextRange, value: win32more.Windows.UI.Text.ITextCharacterFormat) -> Void: ...
    @winrt_mixinmethod
    def get_FormattedText(self: win32more.Windows.UI.Text.ITextRange) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def put_FormattedText(self: win32more.Windows.UI.Text.ITextRange, value: win32more.Windows.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def get_EndPosition(self: win32more.Windows.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def put_EndPosition(self: win32more.Windows.UI.Text.ITextRange, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Gravity(self: win32more.Windows.UI.Text.ITextRange) -> win32more.Windows.UI.Text.RangeGravity: ...
    @winrt_mixinmethod
    def put_Gravity(self: win32more.Windows.UI.Text.ITextRange, value: win32more.Windows.UI.Text.RangeGravity) -> Void: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def get_Link(self: win32more.Windows.UI.Text.ITextRange) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Link(self: win32more.Windows.UI.Text.ITextRange, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ParagraphFormat(self: win32more.Windows.UI.Text.ITextRange) -> win32more.Windows.UI.Text.ITextParagraphFormat: ...
    @winrt_mixinmethod
    def put_ParagraphFormat(self: win32more.Windows.UI.Text.ITextRange, value: win32more.Windows.UI.Text.ITextParagraphFormat) -> Void: ...
    @winrt_mixinmethod
    def get_StartPosition(self: win32more.Windows.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def put_StartPosition(self: win32more.Windows.UI.Text.ITextRange, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_StoryLength(self: win32more.Windows.UI.Text.ITextRange) -> Int32: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Text.ITextRange) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Text.ITextRange, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def CanPaste(self: win32more.Windows.UI.Text.ITextRange, format: Int32) -> Boolean: ...
    @winrt_mixinmethod
    def ChangeCase(self: win32more.Windows.UI.Text.ITextRange, value: win32more.Windows.UI.Text.LetterCase) -> Void: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Windows.UI.Text.ITextRange, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Copy(self: win32more.Windows.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def Cut(self: win32more.Windows.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def Delete(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def EndOf(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_mixinmethod
    def FindText(self: win32more.Windows.UI.Text.ITextRange, value: WinRT_String, scanLength: Int32, options: win32more.Windows.UI.Text.FindOptions) -> Int32: ...
    @winrt_mixinmethod
    def GetCharacterUtf32(self: win32more.Windows.UI.Text.ITextRange, value: POINTER(UInt32), offset: Int32) -> Void: ...
    @winrt_mixinmethod
    def GetClone(self: win32more.Windows.UI.Text.ITextRange) -> win32more.Windows.UI.Text.ITextRange: ...
    @winrt_mixinmethod
    def GetIndex(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit) -> Int32: ...
    @winrt_mixinmethod
    def GetPoint(self: win32more.Windows.UI.Text.ITextRange, horizontalAlign: win32more.Windows.UI.Text.HorizontalCharacterAlignment, verticalAlign: win32more.Windows.UI.Text.VerticalCharacterAlignment, options: win32more.Windows.UI.Text.PointOptions, point: POINTER(win32more.Windows.Foundation.Point)) -> Void: ...
    @winrt_mixinmethod
    def GetRect(self: win32more.Windows.UI.Text.ITextRange, options: win32more.Windows.UI.Text.PointOptions, rect: POINTER(win32more.Windows.Foundation.Rect), hit: POINTER(Int32)) -> Void: ...
    @winrt_mixinmethod
    def GetText(self: win32more.Windows.UI.Text.ITextRange, options: win32more.Windows.UI.Text.TextGetOptions, value: POINTER(WinRT_String)) -> Void: ...
    @winrt_mixinmethod
    def GetTextViaStream(self: win32more.Windows.UI.Text.ITextRange, options: win32more.Windows.UI.Text.TextGetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def InRange(self: win32more.Windows.UI.Text.ITextRange, range: win32more.Windows.UI.Text.ITextRange) -> Boolean: ...
    @winrt_mixinmethod
    def InsertImage(self: win32more.Windows.UI.Text.ITextRange, width: Int32, height: Int32, ascent: Int32, verticalAlign: win32more.Windows.UI.Text.VerticalCharacterAlignment, alternateText: WinRT_String, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def InStory(self: win32more.Windows.UI.Text.ITextRange, range: win32more.Windows.UI.Text.ITextRange) -> Boolean: ...
    @winrt_mixinmethod
    def IsEqual(self: win32more.Windows.UI.Text.ITextRange, range: win32more.Windows.UI.Text.ITextRange) -> Boolean: ...
    @winrt_mixinmethod
    def Move(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def MoveEnd(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def MoveStart(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, count: Int32) -> Int32: ...
    @winrt_mixinmethod
    def Paste(self: win32more.Windows.UI.Text.ITextRange, format: Int32) -> Void: ...
    @winrt_mixinmethod
    def ScrollIntoView(self: win32more.Windows.UI.Text.ITextRange, value: win32more.Windows.UI.Text.PointOptions) -> Void: ...
    @winrt_mixinmethod
    def MatchSelection(self: win32more.Windows.UI.Text.ITextRange) -> Void: ...
    @winrt_mixinmethod
    def SetIndex(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, index: Int32, extend: Boolean) -> Void: ...
    @winrt_mixinmethod
    def SetPoint(self: win32more.Windows.UI.Text.ITextRange, point: win32more.Windows.Foundation.Point, options: win32more.Windows.UI.Text.PointOptions, extend: Boolean) -> Void: ...
    @winrt_mixinmethod
    def SetRange(self: win32more.Windows.UI.Text.ITextRange, startPosition: Int32, endPosition: Int32) -> Void: ...
    @winrt_mixinmethod
    def SetText(self: win32more.Windows.UI.Text.ITextRange, options: win32more.Windows.UI.Text.TextSetOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def SetTextViaStream(self: win32more.Windows.UI.Text.ITextRange, options: win32more.Windows.UI.Text.TextSetOptions, value: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Void: ...
    @winrt_mixinmethod
    def StartOf(self: win32more.Windows.UI.Text.ITextRange, unit: win32more.Windows.UI.Text.TextRangeUnit, extend: Boolean) -> Int32: ...
    Character = property(get_Character, put_Character)
    CharacterFormat = property(get_CharacterFormat, put_CharacterFormat)
    ContentLinkInfo = property(get_ContentLinkInfo, put_ContentLinkInfo)
    EndPosition = property(get_EndPosition, put_EndPosition)
    FormattedText = property(get_FormattedText, put_FormattedText)
    Gravity = property(get_Gravity, put_Gravity)
    Length = property(get_Length, None)
    Link = property(get_Link, put_Link)
    ParagraphFormat = property(get_ParagraphFormat, put_ParagraphFormat)
    StartPosition = property(get_StartPosition, put_StartPosition)
    StoryLength = property(get_StoryLength, None)
    Text = property(get_Text, put_Text)
class SelectionOptions(Enum, UInt32):
    StartActive = 1
    AtEndOfLine = 2
    Overtype = 4
    Active = 8
    Replace = 16
class SelectionType(Enum, Int32):
    None_ = 0
    InsertionPoint = 1
    Normal = 2
    InlineShape = 7
    Shape = 8
class TabAlignment(Enum, Int32):
    Left = 0
    Center = 1
    Right = 2
    Decimal = 3
    Bar = 4
class TabLeader(Enum, Int32):
    Spaces = 0
    Dots = 1
    Dashes = 2
    Lines = 3
    ThickLines = 4
    Equals = 5
class _TextConstants_Meta_(ComPtr.__class__):
    pass
class TextConstants(ComPtr, metaclass=_TextConstants_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.TextConstants'
    @winrt_classmethod
    def get_AutoColor(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MinUnitCount(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> Int32: ...
    @winrt_classmethod
    def get_MaxUnitCount(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> Int32: ...
    @winrt_classmethod
    def get_UndefinedColor(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_UndefinedFloatValue(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> Single: ...
    @winrt_classmethod
    def get_UndefinedInt32Value(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> Int32: ...
    @winrt_classmethod
    def get_UndefinedFontStretch(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_classmethod
    def get_UndefinedFontStyle(cls: win32more.Windows.UI.Text.ITextConstantsStatics) -> win32more.Windows.UI.Text.FontStyle: ...
    _TextConstants_Meta_.AutoColor = property(get_AutoColor, None)
    _TextConstants_Meta_.MaxUnitCount = property(get_MaxUnitCount, None)
    _TextConstants_Meta_.MinUnitCount = property(get_MinUnitCount, None)
    _TextConstants_Meta_.UndefinedColor = property(get_UndefinedColor, None)
    _TextConstants_Meta_.UndefinedFloatValue = property(get_UndefinedFloatValue, None)
    _TextConstants_Meta_.UndefinedFontStretch = property(get_UndefinedFontStretch, None)
    _TextConstants_Meta_.UndefinedFontStyle = property(get_UndefinedFontStyle, None)
    _TextConstants_Meta_.UndefinedInt32Value = property(get_UndefinedInt32Value, None)
class TextDecorations(Enum, UInt32):
    None_ = 0
    Underline = 1
    Strikethrough = 2
class TextGetOptions(Enum, UInt32):
    None_ = 0
    AdjustCrlf = 1
    UseCrlf = 2
    UseObjectText = 4
    AllowFinalEop = 8
    NoHidden = 32
    IncludeNumbering = 64
    FormatRtf = 8192
    UseLf = 16777216
class TextRangeUnit(Enum, Int32):
    Character = 0
    Word = 1
    Sentence = 2
    Paragraph = 3
    Line = 4
    Story = 5
    Screen = 6
    Section = 7
    Window = 8
    CharacterFormat = 9
    ParagraphFormat = 10
    Object = 11
    HardParagraph = 12
    Cluster = 13
    Bold = 14
    Italic = 15
    Underline = 16
    Strikethrough = 17
    ProtectedText = 18
    Link = 19
    SmallCaps = 20
    AllCaps = 21
    Hidden = 22
    Outline = 23
    Shadow = 24
    Imprint = 25
    Disabled = 26
    Revised = 27
    Subscript = 28
    Superscript = 29
    FontBound = 30
    LinkProtected = 31
    ContentLink = 32
class TextScript(Enum, Int32):
    Undefined = 0
    Ansi = 1
    EastEurope = 2
    Cyrillic = 3
    Greek = 4
    Turkish = 5
    Hebrew = 6
    Arabic = 7
    Baltic = 8
    Vietnamese = 9
    Default = 10
    Symbol = 11
    Thai = 12
    ShiftJis = 13
    GB2312 = 14
    Hangul = 15
    Big5 = 16
    PC437 = 17
    Oem = 18
    Mac = 19
    Armenian = 20
    Syriac = 21
    Thaana = 22
    Devanagari = 23
    Bengali = 24
    Gurmukhi = 25
    Gujarati = 26
    Oriya = 27
    Tamil = 28
    Telugu = 29
    Kannada = 30
    Malayalam = 31
    Sinhala = 32
    Lao = 33
    Tibetan = 34
    Myanmar = 35
    Georgian = 36
    Jamo = 37
    Ethiopic = 38
    Cherokee = 39
    Aboriginal = 40
    Ogham = 41
    Runic = 42
    Khmer = 43
    Mongolian = 44
    Braille = 45
    Yi = 46
    Limbu = 47
    TaiLe = 48
    NewTaiLue = 49
    SylotiNagri = 50
    Kharoshthi = 51
    Kayahli = 52
    UnicodeSymbol = 53
    Emoji = 54
    Glagolitic = 55
    Lisu = 56
    Vai = 57
    NKo = 58
    Osmanya = 59
    PhagsPa = 60
    Gothic = 61
    Deseret = 62
    Tifinagh = 63
class TextSetOptions(Enum, UInt32):
    None_ = 0
    UnicodeBidi = 1
    Unlink = 8
    Unhide = 16
    CheckTextLimit = 32
    FormatRtf = 8192
    ApplyRtfDocumentDefaults = 16384
class UnderlineType(Enum, Int32):
    Undefined = 0
    None_ = 1
    Single = 2
    Words = 3
    Double = 4
    Dotted = 5
    Dash = 6
    DashDot = 7
    DashDotDot = 8
    Wave = 9
    Thick = 10
    Thin = 11
    DoubleWave = 12
    HeavyWave = 13
    LongDash = 14
    ThickDash = 15
    ThickDashDot = 16
    ThickDashDotDot = 17
    ThickDotted = 18
    ThickLongDash = 19
class VerticalCharacterAlignment(Enum, Int32):
    Top = 0
    Baseline = 1
    Bottom = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.Geolocation
import win32more.Windows.Win32.Devices.Sensors
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
GNSS_DRIVER_VERSION_1: UInt32 = 1
GNSS_DRIVER_VERSION_2: UInt32 = 2
GNSS_DRIVER_VERSION_3: UInt32 = 3
GNSS_DRIVER_VERSION_4: UInt32 = 4
GNSS_DRIVER_VERSION_5: UInt32 = 5
GNSS_DRIVER_VERSION_6: UInt32 = 6
IOCTL_GNSS_SEND_PLATFORM_CAPABILITY: UInt32 = 2228228
IOCTL_GNSS_GET_DEVICE_CAPABILITY: UInt32 = 2228232
IOCTL_GNSS_SEND_DRIVERCOMMAND: UInt32 = 2228236
IOCTL_GNSS_START_FIXSESSION: UInt32 = 2228288
IOCTL_GNSS_MODIFY_FIXSESSION: UInt32 = 2228292
IOCTL_GNSS_STOP_FIXSESSION: UInt32 = 2228296
IOCTL_GNSS_GET_FIXDATA: UInt32 = 2228300
IOCTL_GNSS_INJECT_AGNSS: UInt32 = 2228352
IOCTL_GNSS_LISTEN_AGNSS: UInt32 = 2228416
IOCTL_GNSS_LISTEN_ERROR: UInt32 = 2228420
IOCTL_GNSS_LISTEN_NI: UInt32 = 2228480
IOCTL_GNSS_SET_SUPL_HSLP: UInt32 = 2228484
IOCTL_GNSS_CONFIG_SUPL_CERT: UInt32 = 2228488
IOCTL_GNSS_RESPOND_NI: UInt32 = 2228492
IOCTL_GNSS_EXECUTE_CWTEST: UInt32 = 2228496
IOCTL_GNSS_EXECUTE_SELFTEST: UInt32 = 2228500
IOCTL_GNSS_GET_CHIPSETINFO: UInt32 = 2228504
IOCTL_GNSS_LISTEN_NMEA: UInt32 = 2228508
IOCTL_GNSS_SET_V2UPL_CONFIG: UInt32 = 2228512
IOCTL_GNSS_CREATE_GEOFENCE: UInt32 = 2228544
IOCTL_GNSS_DELETE_GEOFENCE: UInt32 = 2228548
IOCTL_GNSS_LISTEN_GEOFENCE_ALERT: UInt32 = 2228552
IOCTL_GNSS_LISTEN_GEOFENCES_TRACKINGSTATUS: UInt32 = 2228556
IOCTL_GNSS_LISTEN_DRIVER_REQUEST: UInt32 = 2228608
IOCTL_GNSS_START_BREADCRUMBING: UInt32 = 2228672
IOCTL_GNSS_STOP_BREADCRUMBING: UInt32 = 2228676
IOCTL_GNSS_LISTEN_BREADCRUMBING_ALERT: UInt32 = 2228680
IOCTL_GNSS_POP_BREADCRUMBS: UInt32 = 2228684
GNSS_AGNSSFORMAT_XTRA1: UInt32 = 1
GNSS_AGNSSFORMAT_XTRA2: UInt32 = 2
GNSS_AGNSSFORMAT_LTO: UInt32 = 4
GNSS_AGNSSFORMAT_XTRA3: UInt32 = 8
GNSS_AGNSSFORMAT_XTRA3_1: UInt32 = 16
GNSS_AGNSSFORMAT_XTRA3_2: UInt32 = 32
GNSS_AGNSSFORMAT_XTRA_INT: UInt32 = 64
MAX_SERVER_URL_NAME: UInt32 = 260
MIN_GEOFENCES_REQUIRED: UInt32 = 100
BREADCRUMBING_UNSUPPORTED: UInt32 = 0
BREADCRUMBING_VERSION_1: UInt32 = 1
MIN_BREADCRUMBS_SUPPORTED: UInt32 = 120
GNSS_SATELLITE_ANY: UInt32 = 0
GNSS_SATELLITE_GPS: UInt32 = 1
GNSS_SATELLITE_GLONASS: UInt32 = 2
GNSS_SATELLITE_BEIDOU: UInt32 = 4
GNSS_SATELLITE_GALILEO: UInt32 = 8
GNSS_OPERMODE_ANY: UInt32 = 0
GNSS_OPERMODE_MSA: UInt32 = 1
GNSS_OPERMODE_MSB: UInt32 = 2
GNSS_OPERMODE_MSS: UInt32 = 4
GNSS_OPERMODE_CELLID: UInt32 = 8
GNSS_OPERMODE_AFLT: UInt32 = 16
GNSS_OPERMODE_OTDOA: UInt32 = 32
GNSS_NMEALOGGING_NONE: UInt32 = 0
GNSS_NMEALOGGING_ALL: UInt32 = 255
GNSS_FIXDETAIL_BASIC: UInt32 = 1
GNSS_FIXDETAIL_ACCURACY: UInt32 = 2
GNSS_FIXDETAIL_SATELLITE: UInt32 = 4
GNSS_MAXSATELLITE: UInt32 = 64
GNSS_GEOFENCESUPPORT_SUPPORTED: UInt32 = 1
GNSS_GEOFENCESUPPORT_CIRCLE: UInt32 = 2
LOCATION_API_VERSION: UInt32 = 1
GUID_DEVINTERFACE_GNSS: Guid = Guid('{3336e5e4-018a-4669-84c5-bd05f3bd368b}')
CivicAddressReport = Guid('{d39e7bdd-7d05-46b8-8721-80cf035f57d7}')
CivicAddressReportFactory = Guid('{2a11f42c-3e81-4ad4-9cbe-45579d89671a}')
DefaultLocation = Guid('{8b7fbfe0-5cd7-494a-af8c-283a65707506}')
DispCivicAddressReport = Guid('{4c596aec-8544-4082-ba9f-eb0a7d8e65c6}')
DispLatLongReport = Guid('{7a7c3277-8f84-4636-95b2-ebb5507ff77e}')
class GNSS_AGNSS_INJECT(Structure):
    Size: UInt32
    Version: UInt32
    InjectionType: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_TYPE
    InjectionStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    InjectionDataSize: UInt32
    Unused: Byte * 512
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Time: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_INJECTTIME
        Position: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_INJECTPOSITION
        BlobData: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_INJECTBLOB
class GNSS_AGNSS_INJECTBLOB(Structure):
    Size: UInt32
    Version: UInt32
    BlobOui: UInt32
    BlobVersion: UInt32
    AgnssFormat: UInt32
    BlobSize: UInt32
    BlobData: Byte * 1
class GNSS_AGNSS_INJECTPOSITION(Structure):
    Size: UInt32
    Version: UInt32
    Age: UInt32
    BasicData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_BASIC
    AccuracyData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_ACCURACY
class GNSS_AGNSS_INJECTTIME(Structure):
    Size: UInt32
    Version: UInt32
    UtcTime: win32more.Windows.Win32.Foundation.FILETIME
    TimeUncertainty: UInt32
class GNSS_AGNSS_REQUEST_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    RequestType: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_TYPE
    BlobFormat: UInt32
GNSS_AGNSS_REQUEST_TYPE = Int32
GNSS_AGNSS_TimeInjection: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_TYPE = 1
GNSS_AGNSS_PositionInjection: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_TYPE = 2
GNSS_AGNSS_BlobInjection: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_TYPE = 3
class GNSS_BREADCRUMBING_ALERT_DATA(Structure):
    Size: UInt32
    Version: UInt32
    Unused: Byte * 512
class GNSS_BREADCRUMBING_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    MaximumHorizontalUncertainty: UInt32
    MinDistanceBetweenFixes: UInt32
    MaximumErrorTimeoutMs: UInt32
    Unused: Byte * 512
class GNSS_BREADCRUMB_LIST(Structure):
    Size: UInt32
    Version: UInt32
    NumCrumbs: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        v1: win32more.Windows.Win32.Devices.Geolocation.GNSS_BREADCRUMB_V1 * 50
class GNSS_BREADCRUMB_V1(Structure):
    FixTimeStamp: win32more.Windows.Win32.Foundation.FILETIME
    Latitude: Double
    Longitude: Double
    HorizontalAccuracy: UInt32
    Speed: UInt16
    SpeedAccuracy: UInt16
    Altitude: Int16
    AltitudeAccuracy: UInt16
    Heading: Int16
    HeadingAccuracy: Byte
    FixSuccess: Byte
class GNSS_CHIPSETINFO(Structure):
    Size: UInt32
    Version: UInt32
    ManufacturerID: Char * 25
    HardwareID: Char * 25
    FirmwareVersion: Char * 20
    Unused: Byte * 512
class GNSS_CONTINUOUSTRACKING_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    PreferredInterval: UInt32
class GNSS_CP_NI_INFO(Structure):
    Size: UInt32
    Version: UInt32
    RequestorId: Char * 260
    NotificationText: Char * 260
class GNSS_CWTESTDATA(Structure):
    Size: UInt32
    Version: UInt32
    TestResultStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    SignalToNoiseRatio: Double
    Frequency: Double
    Unused: Byte * 512
class GNSS_DEVICE_CAPABILITY(Structure):
    Size: UInt32
    Version: UInt32
    SupportMultipleFixSessions: win32more.Windows.Win32.Foundation.BOOL
    SupportMultipleAppSessions: win32more.Windows.Win32.Foundation.BOOL
    RequireAGnssInjection: win32more.Windows.Win32.Foundation.BOOL
    AgnssFormatSupported: UInt32
    AgnssFormatPreferred: UInt32
    SupportDistanceTracking: win32more.Windows.Win32.Foundation.BOOL
    SupportContinuousTracking: win32more.Windows.Win32.Foundation.BOOL
    Reserved1: UInt32
    Reserved2: win32more.Windows.Win32.Foundation.BOOL
    Reserved3: win32more.Windows.Win32.Foundation.BOOL
    Reserved4: win32more.Windows.Win32.Foundation.BOOL
    Reserved5: win32more.Windows.Win32.Foundation.BOOL
    GeofencingSupport: UInt32
    Reserved6: win32more.Windows.Win32.Foundation.BOOL
    Reserved7: win32more.Windows.Win32.Foundation.BOOL
    SupportCpLocation: win32more.Windows.Win32.Foundation.BOOL
    SupportUplV2: win32more.Windows.Win32.Foundation.BOOL
    SupportSuplV1: win32more.Windows.Win32.Foundation.BOOL
    SupportSuplV2: win32more.Windows.Win32.Foundation.BOOL
    SupportedSuplVersion: win32more.Windows.Win32.Devices.Geolocation.GNSS_SUPL_VERSION
    MaxGeofencesSupported: UInt32
    SupportMultipleSuplRootCert: win32more.Windows.Win32.Foundation.BOOL
    GnssBreadCrumbPayloadVersion: UInt32
    MaxGnssBreadCrumbFixes: UInt32
    Unused: Byte * 496
class GNSS_DISTANCETRACKING_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    MovementThreshold: UInt32
class GNSS_DRIVERCOMMAND_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    CommandType: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE
    Reserved: UInt32
    CommandDataSize: UInt32
    Unused: Byte * 512
    CommandData: Byte * 1
GNSS_DRIVERCOMMAND_TYPE = Int32
GNSS_SetLocationServiceEnabled: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 1
GNSS_SetLocationNIRequestAllowed: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 2
GNSS_ForceSatelliteSystem: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 3
GNSS_ForceOperationMode: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 4
GNSS_ResetEngine: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 9
GNSS_ClearAgnssData: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 10
GNSS_SetSuplVersion: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 12
GNSS_SetNMEALogging: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 13
GNSS_SetUplServerAccessInterval: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 14
GNSS_SetNiTimeoutInterval: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 15
GNSS_ResetGeofencesTracking: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 16
GNSS_SetSuplVersion2: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 17
GNSS_CustomCommand: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVERCOMMAND_TYPE = 256
GNSS_DRIVER_REQUEST = Int32
SUPL_CONFIG_DATA: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVER_REQUEST = 1
class GNSS_DRIVER_REQUEST_DATA(Structure):
    Size: UInt32
    Version: UInt32
    Request: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVER_REQUEST
    RequestFlag: UInt32
class GNSS_ERRORINFO(Structure):
    Size: UInt32
    Version: UInt32
    ErrorCode: UInt32
    IsRecoverable: win32more.Windows.Win32.Foundation.BOOL
    ErrorDescription: Char * 256
    Unused: Byte * 512
class GNSS_EVENT(Structure):
    Size: UInt32
    Version: UInt32
    EventType: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE
    EventDataSize: UInt32
    Unused: Byte * 512
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        FixData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA
        AgnssRequest: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_PARAM
        NiRequest: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_REQUEST_PARAM
        ErrorInformation: win32more.Windows.Win32.Devices.Geolocation.GNSS_ERRORINFO
        NmeaData: win32more.Windows.Win32.Devices.Geolocation.GNSS_NMEA_DATA
        GeofenceAlertData: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_ALERT_DATA
        BreadcrumbAlertData: win32more.Windows.Win32.Devices.Geolocation.GNSS_BREADCRUMBING_ALERT_DATA
        GeofencesTrackingStatus: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCES_TRACKINGSTATUS_DATA
        DriverRequestData: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVER_REQUEST_DATA
        CustomData: Byte * 1
class GNSS_EVENT_2(Structure):
    Size: UInt32
    Version: UInt32
    EventType: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE
    EventDataSize: UInt32
    Unused: Byte * 512
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        FixData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA
        FixData2: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_2
        AgnssRequest: win32more.Windows.Win32.Devices.Geolocation.GNSS_AGNSS_REQUEST_PARAM
        NiRequest: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_REQUEST_PARAM
        ErrorInformation: win32more.Windows.Win32.Devices.Geolocation.GNSS_ERRORINFO
        NmeaData: win32more.Windows.Win32.Devices.Geolocation.GNSS_NMEA_DATA
        GeofenceAlertData: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_ALERT_DATA
        BreadcrumbAlertData: win32more.Windows.Win32.Devices.Geolocation.GNSS_BREADCRUMBING_ALERT_DATA
        GeofencesTrackingStatus: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCES_TRACKINGSTATUS_DATA
        DriverRequestData: win32more.Windows.Win32.Devices.Geolocation.GNSS_DRIVER_REQUEST_DATA
        CustomData: Byte * 1
GNSS_EVENT_TYPE = Int32
GNSS_Event_FixAvailable: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 1
GNSS_Event_RequireAgnss: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 2
GNSS_Event_Error: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 3
GNSS_Event_NiRequest: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 12
GNSS_Event_NmeaData: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 13
GNSS_Event_GeofenceAlertData: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 14
GNSS_Event_GeofencesTrackingStatus: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 15
GNSS_Event_DriverRequest: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 16
GNSS_Event_BreadcrumbAlertEvent: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 17
GNSS_Event_FixAvailable_2: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 18
GNSS_Event_Custom: win32more.Windows.Win32.Devices.Geolocation.GNSS_EVENT_TYPE = 32768
class GNSS_FIXDATA(Structure):
    Size: UInt32
    Version: UInt32
    FixSessionID: UInt32
    FixTimeStamp: win32more.Windows.Win32.Foundation.FILETIME
    IsFinalFix: win32more.Windows.Win32.Foundation.BOOL
    FixStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    FixLevelOfDetails: UInt32
    BasicData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_BASIC
    AccuracyData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_ACCURACY
    SatelliteData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_SATELLITE
class GNSS_FIXDATA_2(Structure):
    Size: UInt32
    Version: UInt32
    FixSessionID: UInt32
    FixTimeStamp: win32more.Windows.Win32.Foundation.FILETIME
    IsFinalFix: win32more.Windows.Win32.Foundation.BOOL
    FixStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    FixLevelOfDetails: UInt32
    BasicData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_BASIC_2
    AccuracyData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_ACCURACY_2
    SatelliteData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_SATELLITE
class GNSS_FIXDATA_ACCURACY(Structure):
    Size: UInt32
    Version: UInt32
    HorizontalAccuracy: UInt32
    HorizontalErrorMajorAxis: UInt32
    HorizontalErrorMinorAxis: UInt32
    HorizontalErrorAngle: UInt32
    HeadingAccuracy: UInt32
    AltitudeAccuracy: UInt32
    SpeedAccuracy: UInt32
    HorizontalConfidence: UInt32
    HeadingConfidence: UInt32
    AltitudeConfidence: UInt32
    SpeedConfidence: UInt32
    PositionDilutionOfPrecision: Single
    HorizontalDilutionOfPrecision: Single
    VerticalDilutionOfPrecision: Single
class GNSS_FIXDATA_ACCURACY_2(Structure):
    Size: UInt32
    Version: UInt32
    HorizontalAccuracy: Double
    HorizontalErrorMajorAxis: Double
    HorizontalErrorMinorAxis: Double
    HorizontalErrorAngle: Double
    HeadingAccuracy: Double
    AltitudeAccuracy: Double
    SpeedAccuracy: Double
    HorizontalConfidence: UInt32
    HeadingConfidence: UInt32
    AltitudeConfidence: UInt32
    SpeedConfidence: UInt32
    PositionDilutionOfPrecision: Double
    HorizontalDilutionOfPrecision: Double
    VerticalDilutionOfPrecision: Double
    GeometricDilutionOfPrecision: Double
    TimeDilutionOfPrecision: Double
class GNSS_FIXDATA_BASIC(Structure):
    Size: UInt32
    Version: UInt32
    Latitude: Double
    Longitude: Double
    Altitude: Double
    Speed: Double
    Heading: Double
class GNSS_FIXDATA_BASIC_2(Structure):
    Size: UInt32
    Version: UInt32
    Latitude: Double
    Longitude: Double
    Altitude: Double
    Speed: Double
    Heading: Double
    AltitudeEllipsoid: Double
class GNSS_FIXDATA_SATELLITE(Structure):
    Size: UInt32
    Version: UInt32
    SatelliteCount: UInt32
    SatelliteArray: win32more.Windows.Win32.Devices.Geolocation.GNSS_SATELLITEINFO * 64
GNSS_FIXSESSIONTYPE = Int32
GNSS_FixSession_SingleShot: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXSESSIONTYPE = 1
GNSS_FixSession_DistanceTracking: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXSESSIONTYPE = 2
GNSS_FixSession_ContinuousTracking: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXSESSIONTYPE = 3
GNSS_FixSession_LKG: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXSESSIONTYPE = 4
class GNSS_FIXSESSION_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    FixSessionID: UInt32
    SessionType: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXSESSIONTYPE
    HorizontalAccuracy: UInt32
    HorizontalConfidence: UInt32
    Reserved: UInt32 * 9
    FixLevelOfDetails: UInt32
    Anonymous: _Anonymous_e__Union
    Unused: Byte * 256
    class _Anonymous_e__Union(Union):
        SingleShotParam: win32more.Windows.Win32.Devices.Geolocation.GNSS_SINGLESHOT_PARAM
        DistanceParam: win32more.Windows.Win32.Devices.Geolocation.GNSS_DISTANCETRACKING_PARAM
        ContinuousParam: win32more.Windows.Win32.Devices.Geolocation.GNSS_CONTINUOUSTRACKING_PARAM
        LkgFixParam: win32more.Windows.Win32.Devices.Geolocation.GNSS_LKGFIX_PARAM
        UnusedParam: Byte * 268
class GNSS_GEOFENCES_TRACKINGSTATUS_DATA(Structure):
    Size: UInt32
    Version: UInt32
    Status: win32more.Windows.Win32.Foundation.NTSTATUS
    StatusTimeStamp: win32more.Windows.Win32.Foundation.FILETIME
    Unused: Byte * 512
class GNSS_GEOFENCE_ALERT_DATA(Structure):
    Size: UInt32
    Version: UInt32
    GeofenceID: UInt32
    GeofenceState: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_STATE
    FixBasicData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_BASIC
    FixAccuracyData: win32more.Windows.Win32.Devices.Geolocation.GNSS_FIXDATA_ACCURACY
    Unused: Byte * 512
class GNSS_GEOFENCE_CREATE_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    AlertTypes: UInt32
    InitialState: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_STATE
    Boundary: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOREGION
    Unused: Byte * 512
class GNSS_GEOFENCE_CREATE_RESPONSE(Structure):
    Size: UInt32
    Version: UInt32
    CreationStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    GeofenceID: UInt32
    Unused: Byte * 512
class GNSS_GEOFENCE_DELETE_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    GeofenceID: UInt32
    Unused: Byte * 512
GNSS_GEOFENCE_STATE = Int32
GNSS_GeofenceState_Unknown: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_STATE = 0
GNSS_GeofenceState_Entered: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_STATE = 1
GNSS_GeofenceState_Exited: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOFENCE_STATE = 2
class GNSS_GEOREGION(Structure):
    Size: UInt32
    Version: UInt32
    GeoRegionType: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOREGIONTYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Circle: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOREGION_CIRCLE
        Unused: Byte * 512
GNSS_GEOREGIONTYPE = Int32
GNSS_GeoRegion_Circle: win32more.Windows.Win32.Devices.Geolocation.GNSS_GEOREGIONTYPE = 1
class GNSS_GEOREGION_CIRCLE(Structure):
    Latitude: Double
    Longitude: Double
    RadiusInMeters: Double
class GNSS_LKGFIX_PARAM(Structure):
    Size: UInt32
    Version: UInt32
GNSS_NI_NOTIFICATION_TYPE = Int32
GNSS_NI_NoNotifyNoVerify: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_NOTIFICATION_TYPE = 1
GNSS_NI_NotifyOnly: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_NOTIFICATION_TYPE = 2
GNSS_NI_NotifyVerifyDefaultAllow: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_NOTIFICATION_TYPE = 3
GNSS_NI_NotifyVerifyDefaultNotAllow: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_NOTIFICATION_TYPE = 4
GNSS_NI_PrivacyOverride: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_NOTIFICATION_TYPE = 5
GNSS_NI_PLANE_TYPE = Int32
GNSS_NI_SUPL: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_PLANE_TYPE = 1
GNSS_NI_CP: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_PLANE_TYPE = 2
GNSS_NI_V2UPL: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_PLANE_TYPE = 3
class GNSS_NI_REQUEST_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    RequestId: UInt32
    RequestType: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_REQUEST_TYPE
    NotificationType: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_NOTIFICATION_TYPE
    RequestPlaneType: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_PLANE_TYPE
    Anonymous: _Anonymous_e__Union
    ResponseTimeInSec: UInt32
    EmergencyLocation: win32more.Windows.Win32.Foundation.BOOL
    class _Anonymous_e__Union(Union):
        SuplNiInfo: win32more.Windows.Win32.Devices.Geolocation.GNSS_SUPL_NI_INFO
        CpNiInfo: win32more.Windows.Win32.Devices.Geolocation.GNSS_CP_NI_INFO
        V2UplNiInfo: win32more.Windows.Win32.Devices.Geolocation.GNSS_V2UPL_NI_INFO
GNSS_NI_REQUEST_TYPE = Int32
GNSS_NI_Request_SingleShot: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_REQUEST_TYPE = 1
GNSS_NI_Request_AreaTrigger: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_REQUEST_TYPE = 2
class GNSS_NI_RESPONSE(Structure):
    Size: UInt32
    Version: UInt32
    RequestId: UInt32
    UserResponse: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_USER_RESPONSE
GNSS_NI_USER_RESPONSE = Int32
GNSS_Ni_UserResponseAccept: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_USER_RESPONSE = 1
GNSS_Ni_UserResponseDeny: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_USER_RESPONSE = 2
GNSS_Ni_UserResponseTimeout: win32more.Windows.Win32.Devices.Geolocation.GNSS_NI_USER_RESPONSE = 3
class GNSS_NMEA_DATA(Structure):
    Size: UInt32
    Version: UInt32
    NmeaSentences: win32more.Windows.Win32.Foundation.CHAR * 256
class GNSS_PLATFORM_CAPABILITY(Structure):
    Size: UInt32
    Version: UInt32
    SupportAgnssInjection: win32more.Windows.Win32.Foundation.BOOL
    AgnssFormatSupported: UInt32
    Unused: Byte * 516
class GNSS_SATELLITEINFO(Structure):
    SatelliteId: UInt32
    UsedInPositiong: win32more.Windows.Win32.Foundation.BOOL
    Elevation: Double
    Azimuth: Double
    SignalToNoiseRatio: Double
class GNSS_SELFTESTCONFIG(Structure):
    Size: UInt32
    Version: UInt32
    TestType: UInt32
    Unused: Byte * 512
    InBufLen: UInt32
    InBuffer: Byte * 1
class GNSS_SELFTESTRESULT(Structure):
    Size: UInt32
    Version: UInt32
    TestResultStatus: win32more.Windows.Win32.Foundation.NTSTATUS
    Result: UInt32
    PinFailedBitMask: UInt32
    Unused: Byte * 512
    OutBufLen: UInt32
    OutBuffer: Byte * 1
class GNSS_SINGLESHOT_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    ResponseTime: UInt32
class GNSS_STOPFIXSESSION_PARAM(Structure):
    Size: UInt32
    Version: UInt32
    FixSessionID: UInt32
    Unused: Byte * 512
GNSS_SUPL_CERT_ACTION = Int32
GNSS_Supl_Cert_Inject: win32more.Windows.Win32.Devices.Geolocation.GNSS_SUPL_CERT_ACTION = 1
GNSS_Supl_Cert_Delete: win32more.Windows.Win32.Devices.Geolocation.GNSS_SUPL_CERT_ACTION = 2
GNSS_Supl_Cert_Purge: win32more.Windows.Win32.Devices.Geolocation.GNSS_SUPL_CERT_ACTION = 3
class GNSS_SUPL_CERT_CONFIG(Structure):
    Size: UInt32
    Version: UInt32
    CertAction: win32more.Windows.Win32.Devices.Geolocation.GNSS_SUPL_CERT_ACTION
    SuplCertName: win32more.Windows.Win32.Foundation.CHAR * 260
    CertSize: UInt32
    Unused: Byte * 512
    CertData: Byte * 1
class GNSS_SUPL_HSLP_CONFIG(Structure):
    Size: UInt32
    Version: UInt32
    SuplHslp: win32more.Windows.Win32.Foundation.CHAR * 260
    SuplHslpFromImsi: win32more.Windows.Win32.Foundation.CHAR * 260
    Reserved: UInt32
    Unused: Byte * 512
class GNSS_SUPL_NI_INFO(Structure):
    Size: UInt32
    Version: UInt32
    RequestorId: Char * 260
    ClientName: Char * 260
    SuplNiUrl: win32more.Windows.Win32.Foundation.CHAR * 260
class GNSS_SUPL_VERSION(Structure):
    MajorVersion: UInt32
    MinorVersion: UInt32
class GNSS_SUPL_VERSION_2(Structure):
    MajorVersion: UInt32
    MinorVersion: UInt32
    ServiceIndicator: UInt32
class GNSS_V2UPL_CONFIG(Structure):
    Size: UInt32
    Version: UInt32
    MPC: win32more.Windows.Win32.Foundation.CHAR * 260
    PDE: win32more.Windows.Win32.Foundation.CHAR * 260
    ApplicationTypeIndicator_MR: Byte
    Unused: Byte * 512
class GNSS_V2UPL_NI_INFO(Structure):
    Size: UInt32
    Version: UInt32
    RequestorId: Char * 260
class ICivicAddressReport(ComPtr):
    extends: win32more.Windows.Win32.Devices.Geolocation.ILocationReport
    _iid_ = Guid('{c0b19f70-4adf-445d-87f2-cad8fd711792}')
    @commethod(6)
    def GetAddressLine1(self, pbstrAddress1: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetAddressLine2(self, pbstrAddress2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetCity(self, pbstrCity: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetStateProvince(self, pbstrStateProvince: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetPostalCode(self, pbstrPostalCode: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetCountryRegion(self, pbstrCountryRegion: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDetailLevel(self, pDetailLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICivicAddressReportFactory(ComPtr):
    extends: win32more.Windows.Win32.Devices.Geolocation.ILocationReportFactory
    _iid_ = Guid('{bf773b93-c64f-4bee-beb2-67c0b8df66e0}')
    @commethod(15)
    def get_CivicAddressReport(self, pVal: POINTER(win32more.Windows.Win32.Devices.Geolocation.IDispCivicAddressReport)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDefaultLocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a65af77e-969a-4a2e-8aca-33bb7cbb1235}')
    @commethod(3)
    def SetReport(self, reportType: POINTER(Guid), pLocationReport: win32more.Windows.Win32.Devices.Geolocation.ILocationReport) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetReport(self, reportType: POINTER(Guid), ppLocationReport: POINTER(win32more.Windows.Win32.Devices.Geolocation.ILocationReport)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDispCivicAddressReport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{16ff1a34-9e30-42c3-b44d-e22513b5767a}')
    @commethod(7)
    def get_AddressLine1(self, pAddress1: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_AddressLine2(self, pAddress2: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_City(self, pCity: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_StateProvince(self, pStateProvince: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_PostalCode(self, pPostalCode: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_CountryRegion(self, pCountryRegion: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_DetailLevel(self, pDetailLevel: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_Timestamp(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDispLatLongReport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{8ae32723-389b-4a11-9957-5bdd48fc9617}')
    @commethod(7)
    def get_Latitude(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Longitude(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ErrorRadius(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Altitude(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_AltitudeError(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Timestamp(self, pVal: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILatLongReport(ComPtr):
    extends: win32more.Windows.Win32.Devices.Geolocation.ILocationReport
    _iid_ = Guid('{7fed806d-0ef8-4f07-80ac-36a0beae3134}')
    @commethod(6)
    def GetLatitude(self, pLatitude: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetLongitude(self, pLongitude: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetErrorRadius(self, pErrorRadius: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetAltitude(self, pAltitude: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetAltitudeError(self, pAltitudeError: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILatLongReportFactory(ComPtr):
    extends: win32more.Windows.Win32.Devices.Geolocation.ILocationReportFactory
    _iid_ = Guid('{3f0804cb-b114-447d-83dd-390174ebb082}')
    @commethod(15)
    def get_LatLongReport(self, pVal: POINTER(win32more.Windows.Win32.Devices.Geolocation.IDispLatLongReport)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILocation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ab2ece69-56d9-4f28-b525-de1b0ee44237}')
    @commethod(3)
    def RegisterForReport(self, pEvents: win32more.Windows.Win32.Devices.Geolocation.ILocationEvents, reportType: POINTER(Guid), dwRequestedReportInterval: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnregisterForReport(self, reportType: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetReport(self, reportType: POINTER(Guid), ppLocationReport: POINTER(win32more.Windows.Win32.Devices.Geolocation.ILocationReport)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetReportStatus(self, reportType: POINTER(Guid), pStatus: POINTER(win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetReportInterval(self, reportType: POINTER(Guid), pMilliseconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetReportInterval(self, reportType: POINTER(Guid), millisecondsRequested: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDesiredAccuracy(self, reportType: POINTER(Guid), pDesiredAccuracy: POINTER(win32more.Windows.Win32.Devices.Sensors.LOCATION_DESIRED_ACCURACY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetDesiredAccuracy(self, reportType: POINTER(Guid), desiredAccuracy: win32more.Windows.Win32.Devices.Sensors.LOCATION_DESIRED_ACCURACY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RequestPermissions(self, hParent: win32more.Windows.Win32.Foundation.HWND, pReportTypes: POINTER(Guid), count: UInt32, fModal: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILocationEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cae02bbf-798b-4508-a207-35a7906dc73d}')
    @commethod(3)
    def OnLocationChanged(self, reportType: POINTER(Guid), pLocationReport: win32more.Windows.Win32.Devices.Geolocation.ILocationReport) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnStatusChanged(self, reportType: POINTER(Guid), newStatus: win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILocationPower(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{193e7729-ab6b-4b12-8617-7596e1bb191c}')
    @commethod(3)
    def Connect(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Disconnect(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILocationReport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c8b7f7ee-75d0-4db9-b62d-7a0f369ca456}')
    @commethod(3)
    def GetSensorID(self, pSensorID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetTimestamp(self, pCreationTime: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetValue(self, pKey: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), pValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ILocationReportFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2daec322-90b2-47e4-bb08-0da841935a6b}')
    @commethod(7)
    def ListenForReports(self, requestedReportInterval: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def StopListeningForReports(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Status(self, pVal: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_ReportInterval(self, pMilliseconds: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_ReportInterval(self, millisecondsRequested: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_DesiredAccuracy(self, pDesiredAccuracy: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_DesiredAccuracy(self, desiredAccuracy: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def RequestPermissions(self, hWnd: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
LOCATION_REPORT_STATUS = Int32
REPORT_NOT_SUPPORTED: win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS = 0
REPORT_ERROR: win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS = 1
REPORT_ACCESS_DENIED: win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS = 2
REPORT_INITIALIZING: win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS = 3
REPORT_RUNNING: win32more.Windows.Win32.Devices.Geolocation.LOCATION_REPORT_STATUS = 4
LatLongReport = Guid('{ed81c073-1f84-4ca8-a161-183c776bc651}')
LatLongReportFactory = Guid('{9dcc3cc8-8609-4863-bad4-03601f4c65e8}')
Location = Guid('{e5b8e079-ee6d-4e33-a438-c87f2e959254}')
class _ICivicAddressReportFactoryEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c96039ff-72ec-4617-89bd-84d88bedc722}')
class _ILatLongReportFactoryEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{16ee6cb7-ab3c-424b-849f-269be551fcbc}')


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.UI.Controls
import win32more.Windows.Win32.UI.HiDpi
import win32more.Windows.Win32.UI.WindowsAndMessaging
DPI_AWARENESS_CONTEXT_UNAWARE: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT = -1
DPI_AWARENESS_CONTEXT_SYSTEM_AWARE: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT = -2
DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT = -3
DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT = -4
DPI_AWARENESS_CONTEXT_UNAWARE_GDISCALED: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT = -5
@winfunctype('UxTheme.dll')
def OpenThemeDataForDpi(hwnd: win32more.Windows.Win32.Foundation.HWND, pszClassList: win32more.Windows.Win32.Foundation.PWSTR, dpi: UInt32) -> win32more.Windows.Win32.UI.Controls.HTHEME: ...
@winfunctype('USER32.dll')
def SetDialogControlDpiChangeBehavior(hWnd: win32more.Windows.Win32.Foundation.HWND, mask: win32more.Windows.Win32.UI.HiDpi.DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS, values: win32more.Windows.Win32.UI.HiDpi.DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDialogControlDpiChangeBehavior(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.UI.HiDpi.DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS: ...
@winfunctype('USER32.dll')
def SetDialogDpiChangeBehavior(hDlg: win32more.Windows.Win32.Foundation.HWND, mask: win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS, values: win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDialogDpiChangeBehavior(hDlg: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS: ...
@winfunctype('USER32.dll')
def GetSystemMetricsForDpi(nIndex: win32more.Windows.Win32.UI.WindowsAndMessaging.SYSTEM_METRICS_INDEX, dpi: UInt32) -> Int32: ...
@winfunctype('USER32.dll')
def AdjustWindowRectExForDpi(lpRect: POINTER(win32more.Windows.Win32.Foundation.RECT), dwStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_STYLE, bMenu: win32more.Windows.Win32.Foundation.BOOL, dwExStyle: win32more.Windows.Win32.UI.WindowsAndMessaging.WINDOW_EX_STYLE, dpi: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LogicalToPhysicalPointForPerMonitorDPI(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def PhysicalToLogicalPointForPerMonitorDPI(hWnd: win32more.Windows.Win32.Foundation.HWND, lpPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SystemParametersInfoForDpi(uiAction: UInt32, uiParam: UInt32, pvParam: VoidPtr, fWinIni: UInt32, dpi: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetThreadDpiAwarenessContext(dpiContext: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT) -> win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT: ...
@winfunctype('USER32.dll')
def GetThreadDpiAwarenessContext() -> win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT: ...
@winfunctype('USER32.dll')
def GetWindowDpiAwarenessContext(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT: ...
@winfunctype('USER32.dll')
def GetAwarenessFromDpiAwarenessContext(value: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT) -> win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS: ...
@winfunctype('USER32.dll')
def GetDpiFromDpiAwarenessContext(value: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT) -> UInt32: ...
@winfunctype('USER32.dll')
def AreDpiAwarenessContextsEqual(dpiContextA: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT, dpiContextB: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def IsValidDpiAwarenessContext(value: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDpiForWindow(hwnd: win32more.Windows.Win32.Foundation.HWND) -> UInt32: ...
@winfunctype('USER32.dll')
def GetDpiForSystem() -> UInt32: ...
@winfunctype('USER32.dll')
def GetSystemDpiForProcess(hProcess: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('USER32.dll')
def EnableNonClientDpiScaling(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def SetProcessDpiAwarenessContext(value: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def GetDpiAwarenessContextForProcess(hProcess: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS_CONTEXT: ...
@winfunctype('USER32.dll')
def SetThreadDpiHostingBehavior(value: win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR) -> win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR: ...
@winfunctype('USER32.dll')
def GetThreadDpiHostingBehavior() -> win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR: ...
@winfunctype('USER32.dll')
def GetWindowDpiHostingBehavior(hwnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR: ...
@winfunctype('api-ms-win-shcore-scaling-l1-1-1.dll')
def SetProcessDpiAwareness(value: win32more.Windows.Win32.UI.HiDpi.PROCESS_DPI_AWARENESS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-shcore-scaling-l1-1-1.dll')
def GetProcessDpiAwareness(hprocess: win32more.Windows.Win32.Foundation.HANDLE, value: POINTER(win32more.Windows.Win32.UI.HiDpi.PROCESS_DPI_AWARENESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('api-ms-win-shcore-scaling-l1-1-1.dll')
def GetDpiForMonitor(hmonitor: win32more.Windows.Win32.Graphics.Gdi.HMONITOR, dpiType: win32more.Windows.Win32.UI.HiDpi.MONITOR_DPI_TYPE, dpiX: POINTER(UInt32), dpiY: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS = Int32
DCDC_DEFAULT: win32more.Windows.Win32.UI.HiDpi.DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS = 0
DCDC_DISABLE_FONT_UPDATE: win32more.Windows.Win32.UI.HiDpi.DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS = 1
DCDC_DISABLE_RELAYOUT: win32more.Windows.Win32.UI.HiDpi.DIALOG_CONTROL_DPI_CHANGE_BEHAVIORS = 2
DIALOG_DPI_CHANGE_BEHAVIORS = Int32
DDC_DEFAULT: win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS = 0
DDC_DISABLE_ALL: win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS = 1
DDC_DISABLE_RESIZE: win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS = 2
DDC_DISABLE_CONTROL_RELAYOUT: win32more.Windows.Win32.UI.HiDpi.DIALOG_DPI_CHANGE_BEHAVIORS = 4
DPI_AWARENESS = Int32
DPI_AWARENESS_INVALID: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS = -1
DPI_AWARENESS_UNAWARE: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS = 0
DPI_AWARENESS_SYSTEM_AWARE: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS = 1
DPI_AWARENESS_PER_MONITOR_AWARE: win32more.Windows.Win32.UI.HiDpi.DPI_AWARENESS = 2
DPI_AWARENESS_CONTEXT = VoidPtr
DPI_HOSTING_BEHAVIOR = Int32
DPI_HOSTING_BEHAVIOR_INVALID: win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR = -1
DPI_HOSTING_BEHAVIOR_DEFAULT: win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR = 0
DPI_HOSTING_BEHAVIOR_MIXED: win32more.Windows.Win32.UI.HiDpi.DPI_HOSTING_BEHAVIOR = 1
MONITOR_DPI_TYPE = Int32
MDT_EFFECTIVE_DPI: win32more.Windows.Win32.UI.HiDpi.MONITOR_DPI_TYPE = 0
MDT_ANGULAR_DPI: win32more.Windows.Win32.UI.HiDpi.MONITOR_DPI_TYPE = 1
MDT_RAW_DPI: win32more.Windows.Win32.UI.HiDpi.MONITOR_DPI_TYPE = 2
MDT_DEFAULT: win32more.Windows.Win32.UI.HiDpi.MONITOR_DPI_TYPE = 0
PROCESS_DPI_AWARENESS = Int32
PROCESS_DPI_UNAWARE: win32more.Windows.Win32.UI.HiDpi.PROCESS_DPI_AWARENESS = 0
PROCESS_SYSTEM_DPI_AWARE: win32more.Windows.Win32.UI.HiDpi.PROCESS_DPI_AWARENESS = 1
PROCESS_PER_MONITOR_DPI_AWARE: win32more.Windows.Win32.UI.HiDpi.PROCESS_DPI_AWARENESS = 2


make_ready(__name__)
